==> datatables.net-plugins-1.13.5.jar: META-INF/resources/webjars/datatables.net-plugins/1.13.5/i18n/el.js <==
(function( factory ) {
	if ( typeof define === 'function' && define.amd ) {
		// AMD
		define( [], factory);
	}
	else if ( typeof exports === 'object' ) {
		// CommonJS
		module.exports = factory();
	}
	// No browser loader - use JSON, ESM, CJS or AMD
}
(function() {
    return {
    "decimal": ",",
    "emptyTable": "Δεν υπάρχουν δεδομένα στον πίνακα",
    "info": "Εμφανίζονται _START_ έως _END_ από _TOTAL_ εγγραφές",
    "infoEmpty": "Εμφανίζονται 0 έως 0 από 0 εγγραφές",
    "infoFiltered": "(φιλτραρισμένες από _MAX_ συνολικά εγγραφές)",
    "infoThousands": ".",
    "lengthMenu": "Δείξε _MENU_ εγγραφές",
    "loadingRecords": "Φόρτωση...",
    "processing": "Επεξεργασία...",
    "search": "Αναζήτηση:",
    "thousands": ".",
    "zeroRecords": "Δεν βρέθηκαν εγγραφές που να ταιριάζουν",
    "paginate": {
        "first": "Πρώτη",
        "previous": "Προηγούμενη",
        "next": "Επόμενη",
        "last": "Τελευταία"
    },
    "aria": {
        "sortAscending": ": ενεργοποιήστε για αύξουσα ταξινόμηση της στήλης",
        "sortDescending": ": ενεργοποιήστε για φθίνουσα ταξινόμηση της στήλης"
    },
    "autoFill": {
        "cancel": "Ακύρωση",
        "fill": "Γέμισμα όλων των κελιών με <i>%d<i><\/i><\/i>",
        "fillHorizontal": "Γέμισμα κελιών οριζόντια",
        "fillVertical": "Γέμισμα κελιών κατακόρυφα"
    },
    "buttons": {
        "collection": "Συλλογή",
        "colvis": "Ορατότητα στηλών",
        "colvisRestore": "Επαναφορά ορατότητας",
        "copy": "Αντιγραφή",
        "copyKeys": "Πατήστε ctrl ή u2318 + C για να αντιγράψετε τα δεδομένα του πίνακα<br \/>στο πρόχειρο. <br \/><br \/>Για ακύρωση, πατήστε το μήνυμα ή πατήστε το πλήκτρο Esc.",
        "copySuccess": {
            "_": " Αντιγράφηκαν %ds γραμμές στο πρόχειρο",
            "1": "Αντιγράφηκε 1 γραμμή στο πρόχειρο"
        },
        "copyTitle": "Αντιγραφή στο πρόχειρο",
        "csv": "CSV",
        "excel": "Excel",
        "pageLength": {
            "_": " Εμφάνιση %d γραμμών",
            "-1": "Εμφάνιση όλων των γραμμών",
            "1": " Εμφάνιση 1 γραμμής"
        },
        "pdf": "PDF",
        "print": "Εκτύπωση",
        "createState": "Δη΀ιουργία κατάστασης",
        "removeAllStates": "Διαγραφή όλων των καταστάσεων",
        "removeState": "Διαγραφή",
        "renameState": "Μετονομασία",
        "savedStates": "Αποθηκευμένες καταστάσεις",
        "stateRestore": "Επαναφορά κατάστασης",
        "updateState": "Ανανέωση κατάστασης"
    },
    "datetime": {
        "amPm": [
            "πμ",
            "μμ"
        ],
        "hours": "Ώρες",
        "minutes": "Λεπτά",
        "next": "Επόμενο",
        "previous": "Προηγούμενο",
        "seconds": "Δευτερόλεπτα",
        "unknown": "Άγνωστο",
        "weekdays": [
            "Κυρ",
            "Δευ",
            "Τρι",
            "Τετ",
            "Πεμ",
            "Παρ",
            "Σαβ"
        ],
        "months": [
            "Ιανουάριος",
            "Φεβρουάριος",
            "Μάρτιος",
            "Απρίλιος"
        ]
    },
    "editor": {
        "close": "Κλείσιμο",
        "create": {
            "button": "Νέο",
            "submit": "Δημιουργία",
            "title": "Δημιουργία νέας εγγραφής"
        },
        "edit": {
            "button": "Επεξεργασία",
            "submit": "Επεξεργασία",
            "title": "Επεξεργασία εγγραφής"
        },
        "error": {
            "system": "Συνέβη ένα λάθος συστήματος (περισσότερες πληροφορίες)"
        },
        "multi": {
            "info": "Τα επιλεγμένα αντικείμενα περιέχουν διαφορετικές τιμές για αυτό το πεδίο. Για να επεξεργαστείτε ή για να ορίσετε την ίδια τιμή για αυτό το πεδίο σε όλα τα αντικείμενα, κάντε κλικ ή π΀τήστε εδώ, διαφορετικά θα διατηρήσουν τις αρχικές τους τιμές.",
            "noMulti": "Αυτό το πεδίο μπορεί να επεξεργαστεί μεμονωμένα, αλλά όχι σε ομάδα. ",
            "restore": "Επαναφορά επιλογών",
            "title": "Αρκετές τιμές"
        },
        "remove": {
            "button": "Διαγραφή",
            "confirm": {
                "_": "Είστε σίγουροι ότι θέλετε να διαγράψετε %d γραμμές;",
                "1": "Είστε σίγουροι ότι θέλετε να διαγράψετε 1 γραμή;"
            },
            "submit": "Διαγραφή",
            "title": "Διαγραφή εγγραφής"
        }
    },
    "searchBuilder": {
        "add": "Εισαγωγή συνθήκης",
        "button": {
            "_": "Φίλτρα εύρεσης (%d)",
            "0": "Δημιουργία φ΀λτρων"
        },
        "clearAll": "Αφαίρεση όλων",
        "condition": "Συνθήκη",
        "conditions": {
            "array": {
                "contains": "Περιέχει",
                "empty": "Κενό",
                "equals": "Ίσο",
                "not": "Όχι",
                "notEmpty": "Όχι κενό",
                "without": "Χωρίς"
            },
            "date": {
                "after": "Μετά",
                "before": "Πριν",
                "between": "Ενδιάμεσα",
                "empty": "Άδειο",
                "equals": "Ίσο",
                "not": "Όχι ίσο",
                "notBetween": "Όχι μεταξύ",
                "notEmpty": "Όχι κενό"
            },
            "number": {
                "between": "Μεταξύ",
                "empty": "Κενό",
                "equals": "Ίσο",
                "gt": "Μεγαλύτερο από",
                "gte": "Μεγαλύτεπο ή ίσο με",
                "lt": "Μικρότερο από",
                "lte": "Μικρότερο ή ίσο με",
                "not": "Όχι",
                "notBetween": "Όχι μεταξύ",
                "notEmpty": "Όχι κενό"
            },
            "string": {
                "contains": "Περιέχει",
                "empty": "Κενό",
                "endsWith": "Τελειώνει με",
                "equals": "Ίσο",
                "not": "Όχι",
                "notEmpty": "Όχι κενό",
                "startsWith": "Αρχίζει με"
            }
        },
        "data": "Δεδομένα",
        "deleteTitle": "Διαγραφή συνθήκης φίλτρου",
        "logicAnd": "και",
        "logicOr": "ή",
        "title": {
            "_": "Φίλτρα εύρεσης (%d)",
            "0": "Φίλτρα εύρεσης"
        },
        "value": "Τιμή"
    },
    "searchPanes": {
        "clearMessage": "Καθαρ΀σμός όλων",
        "collapse": {
            "_": "Φίλτρα αναζήτησης (%d)",
            "0": "Φίλτρα αναζήτησης"
        },
        "count": "{total}",
        "countFiltered": "{shown} ({total})",
        "emptyPanes": "Άδειος πίνακας αναζήτησης",
        "loadMessage": "Φόρτωση πίνακα αναζήτησης",
        "title": "Ενεργά φίλτρα - %d"
    },
    "select": {
        "cells": {
            "_": "%d κελιά επιλέχθηκαν",
            "1": "1 κελί επιλέχθηκε"
        },
        "columns": {
            "_": "%d στήλες επιλέχθηκαν",
            "1": "1 στήλη επιλέχθηκε"
        },
        "rows": {
            "_": "%d γραμμές επιλέχθηκαν",
            "1": "1 γραμμή επιλέχθηκε"
        }
    }
};
}));

==> datatables.net-plugins-2.1.7.jar: META-INF/resources/webjars/datatables.net-plugins/2.1.7/i18n/el.js <==
(function( factory ) {
	if ( typeof define === 'function' && define.amd ) {
		// AMD
		define( [], factory);
	}
	else if ( typeof exports === 'object' ) {
		// CommonJS
		module.exports = factory();
	}
	// No browser loader - use JSON, ESM, CJS or AMD
}
(function() {
    return {
    "decimal": ",",
    "emptyTable": "Δεν υπάρχουν δεδομένα στον πίνακα",
    "info": "Εμφανίζονται _START_ έως _END_ από _TOTAL_ εγγραφές",
    "infoEmpty": "Εμφανίζονται 0 έως 0 από 0 εγγραφές",
    "infoFiltered": "(φιλτραρισμένες από _MAX_ συνολικά εγγραφές)",
    "infoThousands": ".",
    "lengthMenu": "Δείξε _MENU_ εγγραφές",
    "loadingRecords": "Φόρτωση...",
    "processing": "Επεξεργασία...",
    "search": "Αναζήτηση:",
    "thousands": ".",
    "zeroRecords": "Δεν βρέθηκαν εγγραφές που να ταιριάζουν",
    "paginate": {
        "first": "Πρώτη",
        "previous": "Προηγούμενη",
        "next": "Επόμενη",
        "last": "Τελευταία"
    },
    "aria": {
        "sortAscending": ": ενεργοποιήστε για αύξουσα ταξινόμηση της στήλης",
        "sortDescending": ": ενεργοποιήστε για φθίνουσα ταξινόμηση της στήλης"
    },
    "autoFill": {
        "cancel": "Ακύρωση",
        "fill": "Γέμισμα όλων των κελιών με <i>%d<i><\/i><\/i>",
        "fillHorizontal": "Γέμισμα κελιών οριζόντια",
        "fillVertical": "Γέμισμα κελιών κατακόρυφα"
    },
    "buttons": {
        "collection": "Συλλογή",
        "colvis": "Ορατότητα στηλών",
        "colvisRestore": "Επαναφορά ορατότητας",
        "copy": "Αντιγραφή",
        "copyKeys": "Πατήστε ctrl ή u2318 + C για να αντιγράψετε τα δεδομένα του πίνακα<br \/>στο πρόχειρο. <br \/><br \/>Για ακύρωση, πατήστε το μήνυμα ή πατήστε το πλήκτρο Esc.",
        "copySuccess": {
            "_": " Αντιγράφηκαν %ds γραμμές στο πρόχειρο",
            "1": "Αντιγράφηκε 1 γραμμή στο πρόχειρο"
        },
        "copyTitle": "Αντιγραφή στο πρόχειρο",
        "csv": "CSV",
        "excel": "Excel",
        "pageLength": {
            "_": " Εμφάνιση %d γραμμών",
            "-1": "Εμφάνιση όλων των γραμμών",
            "1": " Εμφάνιση 1 γραμμής"
        },
        "pdf": "PDF",
        "print": "Εκτύπωση",
        "createState": "Δημιουργία κατάστασης",
        "removeAllStates": "Διαγραφή όλων των καταστάσεων",
        "removeState": "Διαγραφή",
        "renameState": "Μετονομασία",
        "savedStates": "Αποθηκευμένες καταστάσεις",
        "stateRestore": "Επαναφορά κατάστασης",
        "updateState": "Ανανέωση κατάστασης"
    },
    "datetime": {
        "amPm": [
            "πμ",
            "μμ"
        ],
        "hours": "Ώρες",
        "minutes": "Λεπτά",
        "next": "Επόμενο",
        "previous": "Προηγούμενο",
        "seconds": "Δευτερόλεπτα",
        "unknown": "Άγνωστο",
        "weekdays": [
            "Κυρ",
            "Δευ",
            "Τρι",
            "Τετ",
            "Πεμ",
            "Παρ",
            "Σαβ"
        ],
        "months": [
            "Ιανουάριος",
            "Φεβρουάριος",
            "Μάρτιος",
            "Απρίλιος"
        ]
    },
    "editor": {
        "close": "Κλείσιμο",
        "create": {
            "button": "Νέο",
            "submit": "Δημιουργία",
            "title": "Δημιουργία νέας εγγραφής"
        },
        "edit": {
            "button": "Επεξεργασία",
            "submit": "Επεξεργασία",
            "title": "Επεξεργασία εγγραφής"
        },
        "error": {
            "system": "Συνέβη ένα λάθος συστήματος (περισσότερες πληροφορίες)"
        },
        "multi": {
            "info": "Τα επιλεγμένα αντικείμενα περιέχουν διαφορετικές τιμές για αυτό το πεδίο. Για να επεξεργαστείτε ή για να ορίσετε την ίδια τιμή για αυτό το πεδίο σε όλα τα αντικείμενα, κάντε κλικ ή πατήστε εδώ, διαφορετικά θα διατηρήσουν τις αρχικές τους τιμές.",
            "noMulti": "Αυτό το πεδίο μπορεί να επεξεργαστεί μεμονωμένα, αλλά όχι σε ομάδα. ",
            "restore": "Επαναφορά επιλογών",
            "title": "Αρκετές τιμές"
        },
        "remove": {
            "button": "Διαγραφή",
            "confirm": {
                "_": "Είστε σίγουροι ότι θέλετε να διαγράψετε %d γραμμές;",
                "1": "Είστε σίγουροι ότι θέλετε να διαγράψετε 1 γραμή;"
            },
            "submit": "Διαγραφή",
            "title": "Διαγραφή εγγραφής"
        }
    },
    "searchBuilder": {
        "add": "Εισαγωγή συνθήκης",
        "button": {
            "_": "Φίλτρα εύρεσης (%d)",
            "0": "Δημιουργία φίλτρων"
        },
        "clearAll": "Αφαίρεση όλων",
        "condition": "Συνθήκη",
        "conditions": {
            "array": {
                "contains": "Περιέχει",
                "empty": "Κενό",
                "equals": "Ίσο",
                "not": "Όχι",
                "notEmpty": "Όχι κενό",
                "without": "Χωρίς"
            },
            "date": {
                "after": "Μετά",
                "before": "Πριν",
                "between": "Ενδιάμεσα",
                "empty": "Άδειο",
                "equals": "Ίσο",
                "not": "Όχι ίσο",
                "notBetween": "Όχι μεταξύ",
                "notEmpty": "Όχι κενό"
            },
            "number": {
                "between": "Μεταξύ",
                "empty": "Κενό",
                "equals": "Ίσο",
                "gt": "Μεγαλύτερο από",
                "gte": "Μεγαλύτερο ή ίσο με",
                "lt": "Μικρότερο από",
                "lte": "Μικρότερο ή ίσο με",
                "not": "Όχι",
                "notBetween": "Όχι μεταξύ",
                "notEmpty": "Όχι κενό"
            },
            "string": {
                "contains": "Περιέχει",
                "empty": "Κενό",
                "endsWith": "Τελειώνει με",
                "equals": "Ίσο",
                "not": "Όχι",
                "notEmpty": "Όχι κενό",
                "startsWith": "Αρχίζει με"
            }
        },
        "data": "Δεδομένα",
        "deleteTitle": "Διαγραφή συνθήκης φίλτρου",
        "logicAnd": "και",
        "logicOr": "ή",
        "title": {
            "_": "Φίλτρα εύρεσης (%d)",
            "0": "Φίλτρα εύρεσης"
        },
        "value": "Τιμή"
    },
    "searchPanes": {
        "clearMessage": "Καθαρισμός όλων",
        "collapse": {
            "_": "Φίλτρα αναζήτησης (%d)",
            "0": "Φίλτρα αναζήτησης"
        },
        "count": "{total}",
        "countFiltered": "{shown} ({total})",
        "emptyPanes": "Άδειος πίνακας αναζήτησης",
        "loadMessage": "Φόρτωση πίνακα αναζήτησης",
        "title": "Ενεργά φίλτρα - %d"
    },
    "select": {
        "cells": {
            "_": "%d κελιά επιλέχθηκαν",
            "1": "1 κελί επιλέχθηκε"
        },
        "columns": {
            "_": "%d στήλες επιλέχθηκαν",
            "1": "1 στήλη επιλέχθηκε"
        },
        "rows": {
            "_": "%d γραμμές επιλέχθηκαν",
            "1": "1 γραμμή επιλέχθηκε"
        }
    }
};
}));
